==> cobalt-0.0.1-sources.jar: it/auties/whatsapp/model/message/standard/LocationMessageBuilder.java <==
package it.auties.whatsapp.model.message.standard;

public class LocationMessageBuilder {
    private double latitude;
    private double longitude;
    private java.util.Optional<java.lang.String> name;
    private java.util.Optional<java.lang.String> address;
    private java.util.Optional<java.lang.String> url;
    private boolean live;
    private int accuracy;
    private float speed;
    private int magneticNorthOffset;
    private java.util.Optional<java.lang.String> caption;
    private java.util.Optional<byte[]> thumbnail;
    private java.util.Optional<it.auties.whatsapp.model.info.ContextInfo> contextInfo;

    public LocationMessageBuilder() {
        latitude = 0d;
        longitude = 0d;
        name = java.util.Optional.empty();
        address = java.util.Optional.empty();
        url = java.util.Optional.empty();
        live = false;
        accuracy = 0;
        speed = 0f;
        magneticNorthOffset = 0;
        caption = java.util.Optional.empty();
        thumbnail = java.util.Optional.empty();
        contextInfo = java.util.Optional.empty();
    }

    public LocationMessageBuilder latitude(double latitude) {
        this.latitude = latitude;
        return this;
    }
    public LocationMessageBuilder longitude(double longitude) {
        this.longitude = longitude;
        return this;
    }
    public LocationMessageBuilder name(java.util.Optional<java.lang.String> name) {
        this.name = name;
        return this;
    }
    public LocationMessageBuilder name(java.lang.String name) {
        this.name = java.util.Optional.ofNullable(name);
        return this;
    }
    public LocationMessageBuilder address(java.util.Optional<java.lang.String> address) {
        this.address = address;
        return this;
    }
    public LocationMessageBuilder address(java.lang.String address) {
        this.address = java.util.Optional.ofNullable(address);
        return this;
    }
    public LocationMessageBuilder url(java.util.Optional<java.lang.String> url) {
        this.url = url;
        return this;
    }
    public LocationMessageBuilder url(java.lang.String url) {
        this.url = java.util.Optional.ofNullable(url);
        return this;
    }
    public LocationMessageBuilder live(boolean live) {
        this.live = live;
        return this;
    }
    public LocationMessageBuilder accuracy(int accuracy) {
        this.accuracy = accuracy;
        return this;
    }
    public LocationMessageBuilder speed(float speed) {
        this.speed = speed;
        return this;
    }
    public LocationMessageBuilder magneticNorthOffset(int magneticNorthOffset) {
        this.magneticNorthOffset = magneticNorthOffset;
        return this;
    }
    public LocationMessageBuilder caption(java.util.Optional<java.lang.String> caption) {
        this.caption = caption;
        return this;
    }
    public LocationMessageBuilder caption(java.lang.String caption) {
        this.caption = java.util.Optional.ofNullable(caption);
        return this;
    }
    public LocationMessageBuilder thumbnail(java.util.Optional<byte[]> thumbnail) {
        this.thumbnail = thumbnail;
        return this;
    }
    public LocationMessageBuilder thumbnail(byte[] thumbnail) {
        this.thumbnail = java.util.Optional.ofNullable(thumbnail);
        return this;
    }
    public LocationMessageBuilder contextInfo(java.util.Optional<it.auties.whatsapp.model.info.ContextInfo> contextInfo) {
        this.contextInfo = contextInfo;
        return this;
    }
    public LocationMessageBuilder contextInfo(it.auties.whatsapp.model.info.ContextInfo contextInfo) {
        this.contextInfo = java.util.Optional.ofNullable(contextInfo);
        return this;
    }

    public it.auties.whatsapp.model.message.standard.LocationMessage build() {
        return new it.auties.whatsapp.model.message.standard.LocationMessage(latitude, longitude, name, address, url, live, accuracy, speed, magneticNorthOffset, caption, thumbnail, contextInfo);
    }
}

==> cobalt-0.0.4-sources.jar: it/auties/whatsapp/model/message/standard/LocationMessageBuilder.java <==
package it.auties.whatsapp.model.message.standard;

public class LocationMessageBuilder {
    private double latitude;
    private double longitude;
    private java.lang.String name;
    private java.lang.String address;
    private java.lang.String url;
    private boolean live;
    private int accuracy;
    private float speed;
    private int magneticNorthOffset;
    private java.lang.String caption;
    private byte[] thumbnail;
    private it.auties.whatsapp.model.info.ContextInfo contextInfo;

    public LocationMessageBuilder() {
        latitude = 0d;
        longitude = 0d;
        name = null;
        address = null;
        url = null;
        live = false;
        accuracy = 0;
        speed = 0f;
        magneticNorthOffset = 0;
        caption = null;
        thumbnail = null;
        contextInfo = null;
    }

    public LocationMessageBuilder latitude(double latitude) {
        this.latitude = latitude;
        return this;
    }
    public LocationMessageBuilder longitude(double longitude) {
        this.longitude = longitude;
        return this;
    }
    public LocationMessageBuilder name(java.lang.String name) {
        this.name = name;
        return this;
    }
    public LocationMessageBuilder address(java.lang.String address) {
        this.address = address;
        return this;
    }
    public LocationMessageBuilder url(java.lang.String url) {
        this.url = url;
        return this;
    }
    public LocationMessageBuilder live(boolean live) {
        this.live = live;
        return this;
    }
    public LocationMessageBuilder accuracy(int accuracy) {
        this.accuracy = accuracy;
        return this;
    }
    public LocationMessageBuilder speed(float speed) {
        this.speed = speed;
        return this;
    }
    public LocationMessageBuilder magneticNorthOffset(int magneticNorthOffset) {
        this.magneticNorthOffset = magneticNorthOffset;
        return this;
    }
    public LocationMessageBuilder caption(java.lang.String caption) {
        this.caption = caption;
        return this;
    }
    public LocationMessageBuilder thumbnail(byte[] thumbnail) {
        this.thumbnail = thumbnail;
        return this;
    }
    public LocationMessageBuilder contextInfo(it.auties.whatsapp.model.info.ContextInfo contextInfo) {
        this.contextInfo = contextInfo;
        return this;
    }

    public it.auties.whatsapp.model.message.standard.LocationMessage build() {
        return new it.auties.whatsapp.model.message.standard.LocationMessage(latitude, longitude, name, address, url, live, accuracy, speed, magneticNorthOffset, caption, thumbnail, contextInfo);
    }
}
